@@ -1,3 +1,8 @@
+
+from . import DEFAULT_API_URL, DEFAULT_REQUESTS_PER_MINUTE_LIMIT, logger, ArweaveException, ArweaveNetworkException
+from .stream import PeerStream, GatewayStream
+from .utils import b64dec, arbindec
+
 import io
 import threading
 import time
@@ -6,10 +11,6 @@ import erlang
 import json
 import requests
 
-from . import DEFAULT_API_URL, DEFAULT_REQUESTS_PER_MINUTE_LIMIT, logger, ArweaveException, ArweaveNetworkException
-from .stream import PeerStream, GatewayStream
-from .utils import b64dec, arbindec
-
 def binary_to_term(b):
     # arweave.live seems to replace nonascii chars with this sequence :/
     # occasionally things will work if it's turned back into the etf byte
@@ -1141,7 +1142,12 @@ def reupload(peer, tx):
 
     chunks = generate_transaction_chunks(stream)
     stream = peer.gateway_stream(tx)
-    if chunks['data_root'] != peer.tx_data_root(tx):
+    try:
+        tx_data_root = peer.tx_data_root(tx)
+    except:
+        from ar import Transaction
+        tx_data_root = Transaction.frombytes(peer.unconfirmed_tx2(tx)).data_root
+    if chunks['data_root'] != tx_data_root:
         logger.error(f'{peer.api_url}: Data for {tx} mismatches generated root.')
         return False
     logger.warning(f'uhh trying to reupload {tx}')
